<?php
/**
 * Zerif Lite functions and definitions
 */

function zerif_setup() {    
	
    global $content_width;
	
    if (!isset($content_width)) {
        $content_width = 640;
    }

    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on zerif, use a find and replace
     * to change 'zerif-lite' to the name of your theme in all the template files
     */
    load_theme_textdomain('zerif-lite', get_template_directory() . '/languages'); 

    add_theme_support('automatic-feed-links');

    /*
     * Enable support for Post Thumbnails on posts and pages.
     */
    add_theme_support('post-thumbnails');

    /* Set the image size by cropping the image */
    add_image_size('post-thumbnail', 250, 250, true);
    add_image_size('post-thumbnail-large', 750, 500, true ); /* blog thumbnail */
    add_image_size('post-thumbnail-large-table', 600, 300, true ); /* blog thumbnail for table */
    add_image_size('post-thumbnail-large-mobile', 400, 200, true ); /* blog thumbnail for mobile */
    add_image_size('zerif_project_photo', 285, 214, true);
    add_image_size('zerif_our_team_photo', 174, 174, true);

    /* Register primary menu */
    register_nav_menus(array(
        'primary' => __('Primary Menu', 'zerif-lite'),
    ));

    /* Enable support for Post Formats. */
    add_theme_support('post-formats', array('aside', 'image', 'video', 'quote', 'link'));

    /* Setup the WordPress core custom background feature. */

    if( file_exists(get_stylesheet_directory() . "/images/bg.jpg") ) {
        $zerif_default_image = get_stylesheet_directory_uri() . "/images/bg.jpg";
    } else {
        $zerif_default_image = get_template_directory_uri() . "/images/bg.jpg";
    }
    add_theme_support('custom-background', apply_filters('zerif_custom_background_args', array(
        'default-color' => 'ffffff',
        'default-image' => $zerif_default_image,
    )));

    /* Enable support for HTML5 markup. */
    add_theme_support('html5', array(
        'comment-list',
        'search-form',
        'comment-form',
        'gallery',
    ));
	
	/* Enable support for title-tag */
	add_theme_support( 'title-tag' );

    /* Enable support for custom logo */
	add_theme_support( 'custom-logo', array(
		'flex-width'    => true,
	) );

	/* Custom template tags for this theme. */
	require get_template_directory() . '/inc/template-tags.php';

	/* Custom functions that act independently of the theme templates. */
	require get_template_directory() . '/inc/extras.php';

	/* Customizer additions. */
	require get_template_directory() . '/inc/customizer.php';

	/* tgm-plugin-activation */
    require_once get_template_directory() . '/class-tgm-plugin-activation.php';

	/* Customizer info */
	require_once get_template_directory() . '/inc/customizer-info/class/class-singleton-customizer-info-section.php';


    /* woocommerce support */
	add_theme_support( 'woocommerce' );

	/* selective widget refresh */
	add_theme_support( 'customize-selective-refresh-widgets' );

	/*******************************************/
    /*************  Welcome screen *************/
    /*******************************************/

	if ( is_admin() ) {

        global $zerif_required_actions;

        /*
         * id - unique id; required
         * title
         * description
         * check - check for plugins (if installed)
         * plugin_slug - the plugin's slug (used for installing the plugin)
         *
         */
        $zerif_required_actions = array(
			array(
                "id" => 'zerif-lite-req-ac-frontpage-latest-news',
                "title" => esc_html__( 'Get the one page template' ,'zerif-lite' ),
                "description"=> esc_html__( 'If you just installed Zerif Lite, and are not able to see the one page template, you need to go to Settings -> Reading , Front page displays and select "Your latest posts".','zerif-lite' ),
				"check" => zerif_lite_is_not_latest_posts()
            ),
            array(
                "id" => 'zerif-lite-req-ac-install-pirate-forms',
                "title" => esc_html__( 'Install Pirate Forms' ,'zerif-lite' ),
                "description"=> esc_html__( 'In the next updates, Zerif Lite\'s default contact form will be removed. Please make sure you install the Pirate Forms plugin to keep your site updated, and experience a smooth transition to the latest version.','zerif-lite' ),
                "check" => defined("PIRATE_FORMS_VERSION"),
                "plugin_slug" => 'pirate-forms'
            ),
            array(
                "id" => 'zerif-lite-req-ac-check-pirate-forms',
                "title" => esc_html__( 'Check the contact form after installing Pirate Forms' ,'zerif-lite' ),
                "description"=> esc_html__( "After installing the Pirate Forms plugin, please make sure you check your frontpage contact form is working fine. Also, if you use Zerif Lite in other language(s) please make sure the translation is ok. If not, please translate the contact form again.",'zerif-lite' ),
            ),
	        array(
		        "id" => 'zerif-lite-req-ac-install-themeisle-companion',
		        "title" => esc_html__( 'Install ThemeIsle Companion' ,'zerif-lite' ),
		        "description"=> esc_html__( 'In the next updates, Zerif Lite\'s default widgets will be removed. Please make sure you install the ThemeIsle Companion plugin to keep your site updated, and experience a smooth transition to the latest version.','zerif-lite' ),
		        "check" => defined("THEMEISLE_COMPANION_VERSION"),
		        "plugin_slug" => 'themeisle-companion'
	        )
        );

		require get_template_directory() . '/inc/admin/welcome-screen/welcome-screen.php';
	}

	/***********************************/
	/**************  HOOKS *************/
	/***********************************/

	/* Enables user customization via WordPress plugin API. */
	require get_template_directory() . '/inc/hooks.php';

	add_action( 'zerif_404_title', 'zerif_404_title_function' ); # Outputs the title on 404 pages
	add_action( 'zerif_404_content', 'zerif_404_content_function' ); # Outputs a helpful message on 404 pages

	add_action( 'zerif_page_header', 'zerif_page_header_function' ); # Outputs the title on pages

	add_action( 'zerif_page_header_title_archive', 'zerif_page_header_title_archive_function' ); # Outputs the title on archive pages
	add_action( 'zerif_page_term_description_archive', 'zerif_page_term_description_archive_function' ); # Outputs the term description

	add_action( 'zerif_footer_widgets', 'zerif_footer_widgets_function' ); #Outputs the 3 sidebars in footer

	add_action( 'zerif_our_focus_header_title', 'zerif_our_focus_header_title_function' ); #Outputs the title in Our focus section
	add_action( 'zerif_our_focus_header_subtitle', 'zerif_our_focus_header_subtitle_function' ); #Outputs the subtitle in Our focus section

	add_action( 'zerif_our_team_header_title', 'zerif_our_team_header_title_function' ); #Outputs the title in Our team section
	add_action( 'zerif_our_team_header_subtitle', 'zerif_our_team_header_subtitle_function' ); #Outputs the subtitle in Our team section

	add_action( 'zerif_testimonials_header_title', 'zerif_testimonials_header_title_function' ); #Outputs the title in Testimonials section
	add_action( 'zerif_testimonials_header_subtitle', 'zerif_testimonials_header_subtitle_function' ); #Outputs the subtitle in Testimonials section

	add_action( 'zerif_latest_news_header_title', 'zerif_latest_news_header_title_function' ); #Outputs the title in Latest news section
	add_action( 'zerif_latest_news_header_subtitle', 'zerif_latest_news_header_subtitle_function' ); #Outputs the subtitle in Latest news section

	add_action( 'zerif_big_title_text', 'zerif_big_title_text_function' ); #Outputs the text in Big title section

	add_action( 'zerif_about_us_header_title', 'zerif_about_us_header_title_function' ); #Outputs the title in About us section
	add_action( 'zerif_about_us_header_subtitle', 'zerif_about_us_header_subtitle_function' ); #Outputs the subtitle in About us section

	add_action( 'zerif_sidebar', 'zerif_sidebar_function' ); #Outputs the sidebar

	add_action( 'zerif_primary_navigation', 'zerif_primary_navigation_function' ); #Outputs the navigation menu

    add_filter( 'excerpt_more', 'zerif_excerpt_more' );

}

add_action('after_setup_theme', 'zerif_setup');

/* Migrate logo from theme to core */
function zerif_migrate_logo(){

	$zerif_old_logo = get_theme_mod( 'zerif_logo' );

	if ( ! empty( $zerif_old_logo ) ) {

		$zerif_old_logo_id = attachment_url_to_postid( $zerif_old_logo );
		if ( is_int( $zerif_old_logo_id ) ) {
			set_theme_mod( 'custom_logo', $zerif_old_logo_id );
		}
		remove_theme_mod( 'zerif_logo' );

	}
}

add_action( 'after_setup_theme', 'zerif_migrate_logo' );

function zerif_excerpt_more( $more ) {
    return ' <a href="'.esc_url( get_the_permalink() ).'" rel="nofollow"><span class="sr-only">' . esc_html__('Read more about ', 'zerif-lite').esc_attr( get_the_title() ) . '</span>[&hellip;]</a>';
}

function zerif_lite_is_not_latest_posts() {
	return ('posts' == get_option( 'show_on_front' ) ? true : false);
}

/**
 * Register widgetized area and update sidebar with default widgets.
 */

function zerif_widgets_init() {    

	register_sidebar(array(
        'name' => __('Sidebar', 'zerif-lite'),
        'id' => 'sidebar-1',
        'before_widget' => '<aside id="%1$s" class="widget %2$s">',
        'after_widget' => '</aside>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ));

    register_sidebar(array(
        'name' => __('About us section', 'zerif-lite'),
        'id' => 'sidebar-aboutus',
        'before_widget' => '<span id="%1$s">',
        'after_widget'  => '</span>',
        'before_title' => '<h1 class="widget-title">',
        'after_title' => '</h1>',
    ));

    register_sidebars( 
        3, 
        array(
            'name'          => __('Footer area %d','zerif-lite'),
            'id'            => 'zerif-sidebar-footer',
            'before_widget' => '<aside id="%1$s" class="widget footer-widget-footer %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h1 class="widget-title">',
            'after_title'   => '</h1>'
        ) 
    );
    
}

add_action('widgets_init', 'zerif_widgets_init');

function zerif_slug_fonts_url() {
    $fonts_url = '';
     /* Translators: If there are characters in your language that are not
    * supported by Lora, translate this to 'off'. Do not translate
    * into your own language.
    */
    $lato = _x( 'on', 'Lato font: on or off', 'zerif-lite' );
    $homemade = _x( 'on', 'Homemade font: on or off', 'zerif-lite' );
    /* Translators: If there are characters in your language that are not
    * supported by Open Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $monserrat = _x( 'on', 'Monserrat font: on or off', 'zerif-lite' );

    $zerif_use_safe_font = get_theme_mod('zerif_use_safe_font');
    
    if ( ( 'off' !== $lato || 'off' !== $monserrat || 'off' !== $homemade ) && isset($zerif_use_safe_font) && ($zerif_use_safe_font != 1) ) {
        $font_families = array();

        if ( 'off' !== $lato ) {
            $font_families[] = 'Lato:300,400,700,400italic';
        }
         if ( 'off' !== $monserrat ) {
            $font_families[] = 'Montserrat:400,700';
        }
        
        if ( 'off' !== $homemade ) {
            $font_families[] = 'Homemade Apple';
        }
         $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
         $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
     return $fonts_url;
}
/**
 * Enqueue scripts and styles.
 */

function zerif_scripts() {    

	wp_enqueue_style( 'zerif_font', zerif_slug_fonts_url(), array(), null );

	wp_enqueue_style( 'zerif_font_all', add_query_arg( array( 'family' => urlencode( 'Open Sans:300,300italic,400,400italic,600,600italic,700,700italic,800,800italic' ), 'subset' => urlencode( 'latin' ) ), "//fonts.googleapis.com/css" ) );
    
    wp_enqueue_style( 'zerif_bootstrap_style', get_template_directory_uri() . '/css/bootstrap.css' );
	
    wp_style_add_data( 'zerif_bootstrap_style', 'rtl', 'replace' );

    wp_enqueue_style( 'zerif_fontawesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), 'v1' );

    wp_enqueue_style( 'zerif_style', get_stylesheet_uri(), array( 'zerif_fontawesome' ), 'v1' );

    wp_enqueue_style( 'zerif_responsive_style', get_template_directory_uri() . '/css/responsive.css', array('zerif_style'), 'v1' );

    wp_enqueue_style( 'zerif_ie_style', get_template_directory_uri() . '/css/ie.css', array('zerif_style'), 'v1' );
    wp_style_add_data( 'zerif_ie_style', 'conditional', 'lt IE 9' );

    if ( wp_is_mobile() ){
        
        wp_enqueue_style( 'zerif_style_mobile', get_template_directory_uri() . '/css/style-mobile.css', array('zerif_bootstrap_style', 'zerif_style'),'v1' );
    
    }

    /* Bootstrap script */
    wp_enqueue_script( 'zerif_bootstrap_script', get_template_directory_uri() . '/js/bootstrap.min.js', array("jquery"), '20120206', true );

    /* Knob script */
    wp_enqueue_script( 'zerif_knob_nav', get_template_directory_uri() . '/js/jquery.knob.js', array("jquery"), '20120206', true );

    /* Smootscroll script */
    $zerif_disable_smooth_scroll = get_theme_mod( 'zerif_disable_smooth_scroll' );
    if( isset( $zerif_disable_smooth_scroll ) && ( $zerif_disable_smooth_scroll != 1 ) ):
        wp_enqueue_script( 'zerif_smoothscroll', get_template_directory_uri() . '/js/smoothscroll.js', array("jquery"), '20120206', true );
    endif;  
	
	/* scrollReveal script */
	if ( !wp_is_mobile() ){
		wp_enqueue_script( 'zerif_scrollReveal_script', get_template_directory_uri() . '/js/scrollReveal.js', array("jquery"), '20120206', true  );
	}

    /* zerif script */
    wp_enqueue_script( 'zerif_script', get_template_directory_uri() . '/js/zerif.js', array("jquery", "zerif_knob_nav"), '20120206', true );

    if (is_singular() && comments_open() && get_option('thread_comments')) {

        wp_enqueue_script('comment-reply');

    }

    /* HTML5Shiv*/
    wp_enqueue_script( 'zerif_html5', get_template_directory_uri() . '/js/html5.js');
    wp_script_add_data( 'zerif_html5', 'conditional', 'lt IE 9' );

    /* parallax effect */
    if ( !wp_is_mobile() ){

        /* include parallax only if on frontpage and the parallax effect is activated */
        $zerif_parallax_use = get_theme_mod('zerif_parallax_show');

        if ( !empty($zerif_parallax_use) && ($zerif_parallax_use == 1) && is_front_page() ):

            wp_enqueue_script( 'zerif_parallax', get_template_directory_uri() . '/js/parallax.js', array("jquery"), 'v1', true  );

        endif;
    }

	add_editor_style('/css/custom-editor-style.css');
	
}
add_action('wp_enqueue_scripts', 'zerif_scripts');


/**
 * Adjust content width based on template.
 */
function zerif_adjust_content_width() {
    global $content_width;

	$zerif_change_to_full_width = get_theme_mod( 'zerif_change_to_full_width' );
    if ( is_page_template( 'template-fullwidth.php' ) || is_page_template( 'template-fullwidth-no-title.php' ) || is_page_template( 'woocommerce.php' ) || is_page_template( 'single-download.php' ) || ( is_page_template( 'page.php' ) && !empty($zerif_change_to_full_width) ) )
	    $content_width = 1110;

}
add_action( 'template_redirect', 'zerif_adjust_content_width' );


/**
 * Remove Yoast rel="prev/next" link from header
 */
function zerif_remove_yoast_rel_link() {
	return false;
}
add_filter( 'wpseo_prev_rel_link', 'zerif_remove_yoast_rel_link' );
add_filter( 'wpseo_next_rel_link', 'zerif_remove_yoast_rel_link' );

add_action('tgmpa_register', 'zerif_register_required_plugins');

function zerif_register_required_plugins() {	
	
	$wp_version_nr = get_bloginfo('version');
	
	if( $wp_version_nr < 3.9 ):

		$plugins = array(
			array(
				'name' => 'Widget customizer',
				'slug' => 'widget-customizer', 
				'required' => false 
			),
			array(
				'name'      => 'Pirate Forms',
				'slug'      => 'pirate-forms',
				'required'  => false,
			),
			array(
				'name'      => 'ThemeIsle Companion',
				'slug'      => 'themeisle-companion',
				'required'  => false,
			)
		);
		
	else:
	
		$plugins = array(
			array(
				'name'      => 'Pirate Forms',
				'slug'      => 'pirate-forms',
				'required'  => false,
			),
			array(
				'name'      => 'ThemeIsle Companion',
				'slug'      => 'themeisle-companion',
				'required'  => false,
			)
		);
	
	endif;

    $config = array(
        'default_path' => '',
        'menu' => 'tgmpa-install-plugins',
        'has_notices' => true,
        'dismissable' => true,
        'dismiss_msg' => '',
        'is_automatic' => false,
        'message' => '',
        'strings' => array(
            'page_title' => __('Install Required Plugins', 'zerif-lite'),
            'menu_title' => __('Install Plugins', 'zerif-lite'),
            'installing' => __('Installing Plugin: %s', 'zerif-lite'),
            'oops' => __('Something went wrong with the plugin API.', 'zerif-lite'),
            'notice_can_install_required' => _n_noop('This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.','zerif-lite'),
            'notice_can_install_recommended' => _n_noop('This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.','zerif-lite'),
            'notice_cannot_install' => _n_noop('Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.','zerif-lite'),
            'notice_can_activate_required' => _n_noop('The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.','zerif-lite'),
            'notice_can_activate_recommended' => _n_noop('The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.','zerif-lite'),
            'notice_cannot_activate' => _n_noop('Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.','zerif-lite'),
            'notice_ask_to_update' => _n_noop('The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.','zerif-lite'),
            'notice_cannot_update' => _n_noop('Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.','zerif-lite'),
            'install_link' => _n_noop('Begin installing plugin', 'Begin installing plugins','zerif-lite'),
            'activate_link' => _n_noop('Begin activating plugin', 'Begin activating plugins','zerif-lite'),
            'return' => __('Return to Required Plugins Installer', 'zerif-lite'),
            'plugin_activated' => __('Plugin activated successfully.', 'zerif-lite'),
            'complete' => __('All plugins installed and activated successfully. %s', 'zerif-lite'),
            'nag_type' => 'updated'
        )
    );

    tgmpa($plugins, $config);

}

/* Load Jetpack compatibility file. */

require get_template_directory() . '/inc/jetpack.php';

function zerif_wp_page_menu() {    

	echo '<ul class="nav navbar-nav navbar-right responsive-nav main-nav-list">';

		wp_list_pages(array('title_li' => '', 'depth' => 1));

    echo '</ul>';

}

add_filter('the_title', 'zerif_default_title');

function zerif_default_title($title) {    

	if ($title == '')

        $title = __("Default title",'zerif-lite');

    return $title;

}

/*****************************************/
/******          WIDGETS     *************/
/*****************************************/

add_action('widgets_init', 'zerif_register_widgets');

function zerif_register_widgets() {

	if ( !defined("THEMEISLE_COMPANION_VERSION") ) {

		register_widget( 'zerif_ourfocus' );
		register_widget( 'zerif_testimonial_widget' );
		register_widget( 'zerif_clients_widget' );
		register_widget( 'zerif_team_widget' );
		
	}
	
	
	$zerif_lite_sidebars = array ( 'sidebar-ourfocus' => 'sidebar-ourfocus', 'sidebar-testimonials' => 'sidebar-testimonials', 'sidebar-ourteam' => 'sidebar-ourteam' );
	
	/* Register sidebars */
	foreach ( $zerif_lite_sidebars as $zerif_lite_sidebar ):
		$extra_class = '';
		if( $zerif_lite_sidebar == 'sidebar-ourfocus' ):
		
			$zerif_lite_name = __('Our focus section widgets', 'zerif-lite');
		
		elseif( $zerif_lite_sidebar == 'sidebar-testimonials' ):
			$extra_class = 'feedback-box';
			$zerif_lite_name = __('Testimonials section widgets', 'zerif-lite');
			
		elseif( $zerif_lite_sidebar == 'sidebar-ourteam' ):
		
			$zerif_lite_name = __('Our team section widgets', 'zerif-lite');
			
		else:
		
			$zerif_lite_name = $zerif_lite_sidebar;
			
		endif;
		
        register_sidebar(
            array (
                'name'          => $zerif_lite_name,
                'id'            => $zerif_lite_sidebar,
                'before_widget' => '<span id="%1$s" class="'.$extra_class.'">',
                'after_widget' => '</span>',
            )
        );
		
    endforeach;
	
}

/**************************/
/****** our focus widget */
/************************/

if ( !class_exists( 'zerif_ourfocus' ) ) {

	class zerif_ourfocus extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'ctUp-ads-widget',
				__( 'Zerif - Our focus widget', 'zerif-lite' ),
				array(
					'customize_selective_refresh' => true,
				)
			);
			add_action( 'admin_enqueue_scripts', array( $this, 'widget_scripts' ) );
		}

		function widget_scripts( $hook ) {
			if ( $hook != 'widgets.php' ) {
				return;
			}
			wp_enqueue_media();
			wp_enqueue_script( 'zerif_widget_media_script', get_template_directory_uri() . '/js/widget-media.js', false, '1.1', true );
		}

		function widget( $args, $instance ) {

			extract( $args );

			echo $before_widget;

			?>

			<div class="col-lg-3 col-sm-3 focus-box" data-scrollreveal="enter left after 0.15s over 1s">

				<?php
				if ( ! empty( $instance['image_uri'] ) && ( $instance['image_uri'] != 'Upload Image' ) ) {
					if ( ! empty( $instance['link'] ) ) { ?>
						<a href="<?php echo esc_url( $instance['link'] ); ?>" class="service-icon">
							<?php
							if ( ! empty( $instance['title'] ) ) { ?>
								<span class="sr-only">
			                    <?php _e( 'Go to', 'zerif-lite' ); ?>
			                    <?php echo apply_filters( 'widget_title', $instance['title'] ); ?>
		                    </span>
								<?php
							} ?>

							<i class="pixeden"
							   style="background:url(<?php echo esc_url( $instance['image_uri'] ); ?>) no-repeat center;width:100%; height:100%;"></i>
						</a>
						<?php
					} else { ?>
						<div class="service-icon" tabindex="0">
							<i class="pixeden"
							   style="background:url(<?php echo esc_url( $instance['image_uri'] ); ?>) no-repeat center;width:100%; height:100%;"></i>
							<!-- FOCUS ICON-->
						</div>
						<?php
					} ?>


				<?php } elseif ( ! empty( $instance['custom_media_id'] ) ) {

					$zerif_ourfocus_custom_media_id = wp_get_attachment_image_src( $instance["custom_media_id"] );
					if ( ! empty( $zerif_ourfocus_custom_media_id ) && ! empty( $zerif_ourfocus_custom_media_id[0] ) ) {

						if ( ! empty( $instance['link'] ) ) { ?>
							<a href="<?php echo esc_url( $instance['link'] ); ?>" class="service-icon">
								<?php
								if ( ! empty( $instance['title'] ) ) { ?>
									<span class="sr-only">
			                            <?php _e( 'Go to', 'zerif-lite' ); ?>
			                            <?php echo apply_filters( 'widget_title', $instance['title'] ); ?>
		                            </span>
									<?php
								} ?>
								<i class="pixeden"
								   style="background:url(<?php echo esc_url( $zerif_ourfocus_custom_media_id[0] ); ?>) no-repeat center;width:100%; height:100%;"></i>
							</a>
							<?php
						} else { ?>
							<div class="service-icon" tabindex="0">
								<i class="pixeden"
								   style="background:url(<?php echo esc_url( $zerif_ourfocus_custom_media_id[0] ); ?>) no-repeat center;width:100%; height:100%;"></i>
								<!-- FOCUS ICON-->
							</div>
							<?php
						}
					}

				}
				?>

				<h3 class="red-border-bottom"><?php if ( ! empty( $instance['title'] ) ): echo apply_filters( 'widget_title', $instance['title'] ); endif; ?></h3>
				<!-- FOCUS HEADING -->

				<?php
				if ( ! empty( $instance['text'] ) ) {
					echo '<p>';
					echo htmlspecialchars_decode( apply_filters( 'widget_title', $instance['text'] ) );
					echo '</p>';
				}
				?>

			</div>

			<?php

			echo $after_widget;

		}

		function update( $new_instance, $old_instance ) {

			$instance                        = $old_instance;
			$instance['text']                = stripslashes( wp_filter_post_kses( $new_instance['text'] ) );
			$instance['title']               = strip_tags( $new_instance['title'] );
			$instance['link']                = strip_tags( $new_instance['link'] );
			$instance['image_uri']           = strip_tags( $new_instance['image_uri'] );
			$instance['custom_media_id']     = strip_tags( $new_instance['custom_media_id'] );
			$instance['image_in_customizer'] = strip_tags( $new_instance['image_in_customizer'] );

			return $instance;

		}

		function form( $instance ) {
			?>

			<p>
				<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"
				       id="<?php echo $this->get_field_id( 'title' ); ?>"
				       value="<?php if ( ! empty( $instance['title'] ) ): echo $instance['title']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'text' ); ?>"><?php _e( 'Text', 'zerif-lite' ); ?></label><br/>
				<textarea class="widefat" rows="8" cols="20" name="<?php echo $this->get_field_name( 'text' ); ?>"
				          id="<?php echo $this->get_field_id( 'text' ); ?>"><?php if ( ! empty( $instance['text'] ) ): echo htmlspecialchars_decode( $instance['text'] ); endif; ?></textarea>
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e( 'Link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'link' ); ?>"
				       id="<?php echo $this->get_field_id( 'link' ); ?>"
				       value="<?php if ( ! empty( $instance['link'] ) ): echo esc_url( $instance['link'] ); endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'image_uri' ); ?>"><?php _e( 'Image', 'zerif-lite' ); ?></label><br/>

				<?php
				$image_in_customizer = '';
				$display             = 'none';
				if ( ! empty( $instance['image_in_customizer'] ) && ! empty( $instance['image_uri'] ) ) {
					$image_in_customizer = esc_url( $instance['image_in_customizer'] );
					$display             = 'inline-block';
				} else {
					if ( ! empty( $instance['image_uri'] ) ) {
						$image_in_customizer = esc_url( $instance['image_uri'] );
						$display             = 'inline-block';
					}
				}
				$zerif_image_in_customizer = $this->get_field_name( 'image_in_customizer' );
				?>
				<input type="hidden" class="custom_media_display_in_customizer"
				       name="<?php if ( ! empty( $zerif_image_in_customizer ) ) {
					       echo $zerif_image_in_customizer;
				       } ?>"
				       value="<?php if ( ! empty( $instance['image_in_customizer'] ) ): echo $instance['image_in_customizer']; endif; ?>">
				<img class="custom_media_image" src="<?php echo $image_in_customizer; ?>"
				     style="margin:0;padding:0;max-width:100px;float:left;display:<?php echo $display; ?>"
				     alt="<?php echo __( 'Uploaded image', 'zerif-lite' ); ?>"/><br/>

				<input type="text" class="widefat custom_media_url"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       id="<?php echo $this->get_field_id( 'image_uri' ); ?>"
				       value="<?php if ( ! empty( $instance['image_uri'] ) ): echo $instance['image_uri']; endif; ?>"
				       style="margin-top:5px;">

				<input type="button" class="button button-primary custom_media_button" id="custom_media_button"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       value="<?php _e( 'Upload Image', 'zerif-lite' ); ?>" style="margin-top:5px;">
			</p>

			<input class="custom_media_id" id="<?php echo $this->get_field_id( 'custom_media_id' ); ?>"
			       name="<?php echo $this->get_field_name( 'custom_media_id' ); ?>" type="hidden"
			       value="<?php if ( ! empty( $instance["custom_media_id"] ) ): echo $instance["custom_media_id"]; endif; ?>"/>

			<?php

		}

	}
}

/****************************/
/****** testimonial widget **/
/***************************/

if ( !class_exists( 'zerif_testimonial_widget' ) ) {

	class zerif_testimonial_widget extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'zerif_testim-widget',
				__( 'Zerif - Testimonial widget', 'zerif-lite' ),
				array(
					'customize_selective_refresh' => true,
				)
			);
			add_action( 'admin_enqueue_scripts', array( $this, 'widget_scripts' ) );
		}

		function widget_scripts( $hook ) {
			if ( $hook != 'widgets.php' ) {
				return;
			}
			wp_enqueue_media();
			wp_enqueue_script( 'zerif_widget_media_script', get_template_directory_uri() . '/js/widget-media.js', false, '1.1', true );
		}

		function widget( $args, $instance ) {

			extract( $args );

			$zerif_accessibility = get_theme_mod( 'zerif_accessibility' );
			// open link in a new tab when checkbox "accessibility" is not ticked
			$attribut_new_tab = ( isset( $zerif_accessibility ) && ( $zerif_accessibility != 1 ) ? ' target="_blank"' : '' );

			echo $before_widget;

			?>


			<!-- MESSAGE OF THE CLIENT -->

			<?php if ( ! empty( $instance['text'] ) ): ?>
				<div class="message">
					<?php echo htmlspecialchars_decode( apply_filters( 'widget_title', $instance['text'] ) ); ?>
				</div>
			<?php endif; ?>

			<!-- CLIENT INFORMATION -->

			<div class="client">

				<div class="quote red-text">

					<i class="fa fa-quote-left"></i>

				</div>

				<div class="client-info">

					<a <?php echo $attribut_new_tab; ?>
						class="client-name" <?php if ( ! empty( $instance['link'] ) ): echo 'href="' . esc_url( $instance['link'] ) . '"'; endif; ?>><?php if ( ! empty( $instance['title'] ) ): echo apply_filters( 'widget_title', $instance['title'] ); endif; ?></a>


					<?php if ( ! empty( $instance['details'] ) ): ?>
						<div class="client-company">

							<?php echo apply_filters( 'widget_title', $instance['details'] ); ?>

						</div>
					<?php endif; ?>

				</div>

				<?php

				if ( ! empty( $instance['image_uri'] ) && ( $instance['image_uri'] != 'Upload Image' ) ) {

					echo '<div class="client-image hidden-xs">';

					echo '<img src="' . esc_url( $instance['image_uri'] ) . '" alt="" />';

					echo '</div>';

				} elseif ( ! empty( $instance['custom_media_id'] ) ) {

					$zerif_testimonials_custom_media_id = wp_get_attachment_image_src( $instance["custom_media_id"] );
					$alt                                = get_post_meta( $instance['custom_media_id'], '_wp_attachment_image_alt', true );

					if ( ! empty( $zerif_testimonials_custom_media_id ) && ! empty( $zerif_testimonials_custom_media_id[0] ) ) {

						echo '<div class="client-image hidden-xs">';

						echo '<img src="' . esc_url( $zerif_testimonials_custom_media_id[0] ) . '" alt="' . $alt . '" />';

						echo '</div>';

					}
				}

				?>

			</div>
			<!-- / END CLIENT INFORMATION-->


			<?php

			echo $after_widget;

		}

		function update( $new_instance, $old_instance ) {

			$instance                        = $old_instance;
			$instance['text']                = stripslashes( wp_filter_post_kses( $new_instance['text'] ) );
			$instance['title']               = strip_tags( $new_instance['title'] );
			$instance['details']             = strip_tags( $new_instance['details'] );
			$instance['image_uri']           = strip_tags( $new_instance['image_uri'] );
			$instance['link']                = strip_tags( $new_instance['link'] );
			$instance['custom_media_id']     = strip_tags( $new_instance['custom_media_id'] );
			$instance['image_in_customizer'] = strip_tags( $new_instance['image_in_customizer'] );

			return $instance;

		}

		function form( $instance ) {
			?>

			<p>
				<label
					for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Author', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'title' ); ?>"
				       id="<?php echo $this->get_field_id( 'title' ); ?>"
				       value="<?php if ( ! empty( $instance['title'] ) ): echo $instance['title']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e( 'Author link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'link' ); ?>"
				       id="<?php echo $this->get_field_id( 'link' ); ?>"
				       value="<?php if ( ! empty( $instance['link'] ) ): echo esc_url( $instance['link'] ); endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'details' ); ?>"><?php _e( 'Author details', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'details' ); ?>"
				       id="<?php echo $this->get_field_id( 'details' ); ?>"
				       value="<?php if ( ! empty( $instance['details'] ) ): echo $instance['details']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'text' ); ?>"><?php _e( 'Text', 'zerif-lite' ); ?></label><br/>
				<textarea class="widefat" rows="8" cols="20" name="<?php echo $this->get_field_name( 'text' ); ?>"
				          id="<?php echo $this->get_field_id( 'text' ); ?>"><?php if ( ! empty( $instance['text'] ) ): echo htmlspecialchars_decode( $instance['text'] ); endif; ?></textarea>
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'image_uri' ); ?>"><?php _e( 'Image', 'zerif-lite' ); ?></label><br/>

				<?php
				$image_in_customizer = '';
				$display             = 'none';
				if ( ! empty( $instance['image_in_customizer'] ) && ! empty( $instance['image_uri'] ) ) {
					$image_in_customizer = esc_url( $instance['image_in_customizer'] );
					$display             = 'inline-block';
				} else {
					if ( ! empty( $instance['image_uri'] ) ) {
						$image_in_customizer = esc_url( $instance['image_uri'] );
						$display             = 'inline-block';
					}
				}
				$zerif_image_in_customizer = $this->get_field_name( 'image_in_customizer' );
				?>
				<input type="hidden" class="custom_media_display_in_customizer"
				       name="<?php if ( ! empty( $zerif_image_in_customizer ) ) {
					       echo $zerif_image_in_customizer;
				       } ?>"
				       value="<?php if ( ! empty( $instance['image_in_customizer'] ) ): echo $instance['image_in_customizer']; endif; ?>">
				<img class="custom_media_image" src="<?php echo $image_in_customizer; ?>"
				     style="margin:0;padding:0;max-width:100px;float:left;display:<?php echo $display; ?>"
				     alt="<?php echo __( 'Uploaded image', 'zerif-lite' ); ?>"/><br/>

				<input type="text" class="widefat custom_media_url"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       id="<?php echo $this->get_field_id( 'image_uri' ); ?>"
				       value="<?php if ( ! empty( $instance['image_uri'] ) ): echo $instance['image_uri']; endif; ?>"
				       style="margin-top:5px;">

				<input type="button" class="button button-primary custom_media_button" id="custom_media_button"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       value="<?php _e( 'Upload Image', 'zerif-lite' ); ?>" style="margin-top:5px;">
			</p>

			<input class="custom_media_id" id="<?php echo $this->get_field_id( 'custom_media_id' ); ?>"
			       name="<?php echo $this->get_field_name( 'custom_media_id' ); ?>" type="hidden"
			       value="<?php if ( ! empty( $instance["custom_media_id"] ) ): echo $instance["custom_media_id"]; endif; ?>"/>

			<?php

		}

	}
}

/****************************/
/****** clients widget ******/
/***************************/

if ( !class_exists( 'zerif_clients_widget' ) ) {

	class zerif_clients_widget extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'zerif_clients-widget',
				__( 'Zerif - Clients widget', 'zerif-lite' ),
				array(
					'customize_selective_refresh' => true,
				)
			);
			add_action( 'admin_enqueue_scripts', array( $this, 'widget_scripts' ) );
		}

		function widget_scripts( $hook ) {
			if ( $hook != 'widgets.php' ) {
				return;
			}
			wp_enqueue_media();
			wp_enqueue_script( 'zerif_widget_media_script', get_template_directory_uri() . '/js/widget-media.js', false, '1.1', true );
		}

		function widget( $args, $instance ) {

			extract( $args );

			echo $before_widget;

			?>

			<a href="<?php if ( ! empty( $instance['link'] ) ): echo apply_filters( 'widget_title', $instance['link'] ); endif; ?>">
				<?php
				if ( ! empty( $instance['image_uri'] ) && ( $instance['image_uri'] != 'Upload Image' ) ) {

					echo '<img src="' . esc_url( $instance['image_uri'] ) . '" alt="' . __( 'Client', 'zerif-lite' ) . '">';

				} elseif ( ! empty( $instance['custom_media_id'] ) ) {

					$zerif_clients_custom_media_id = wp_get_attachment_image_src( $instance["custom_media_id"] );
					if ( ! empty( $zerif_clients_custom_media_id ) && ! empty( $zerif_clients_custom_media_id[0] ) ) {

						echo '<img src="' . esc_url( $zerif_clients_custom_media_id[0] ) . '" alt="' . __( 'Client', 'zerif-lite' ) . '">';

					}
				}
				?>
			</a>

			<?php

			echo $after_widget;

		}

		function update( $new_instance, $old_instance ) {

			$instance = $old_instance;

			$instance['link'] = strip_tags( $new_instance['link'] );

			$instance['image_uri'] = strip_tags( $new_instance['image_uri'] );

			$instance['image_in_customizer'] = strip_tags( $new_instance['image_in_customizer'] );

			$instance['custom_media_id'] = strip_tags( $new_instance['custom_media_id'] );

			return $instance;

		}

		function form( $instance ) {
			?>

			<p>
				<label
					for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e( 'Link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'link' ); ?>"
				       id="<?php echo $this->get_field_id( 'link' ); ?>"
				       value="<?php if ( ! empty( $instance['link'] ) ): echo $instance['link']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'image_uri' ); ?>"><?php _e( 'Image', 'zerif-lite' ); ?></label><br/>

				<?php
				$image_in_customizer = '';
				$display             = 'none';
				if ( ! empty( $instance['image_in_customizer'] ) && ! empty( $instance['image_uri'] ) ) {
					$image_in_customizer = esc_url( $instance['image_in_customizer'] );
					$display             = 'inline-block';
				} else {
					if ( ! empty( $instance['image_uri'] ) ) {
						$image_in_customizer = esc_url( $instance['image_uri'] );
						$display             = 'inline-block';
					}
				}
				$zerif_image_in_customizer = $this->get_field_name( 'image_in_customizer' );
				?>
				<input type="hidden" class="custom_media_display_in_customizer"
				       name="<?php if ( ! empty( $zerif_image_in_customizer ) ) {
					       echo $zerif_image_in_customizer;
				       } ?>"
				       value="<?php if ( ! empty( $instance['image_in_customizer'] ) ): echo $instance['image_in_customizer']; endif; ?>">
				<img class="custom_media_image" src="<?php echo $image_in_customizer; ?>"
				     style="margin:0;padding:0;max-width:100px;float:left;display:<?php echo $display; ?>"
				     alt="<?php echo __( 'Uploaded image', 'zerif-lite' ); ?>"/><br/>

				<input type="text" class="widefat custom_media_url"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       id="<?php echo $this->get_field_id( 'image_uri' ); ?>"
				       value="<?php if ( ! empty( $instance['image_uri'] ) ): echo $instance['image_uri']; endif; ?>"
				       style="margin-top:5px;">

				<input type="button" class="button button-primary custom_media_button" id="custom_media_button"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       value="<?php _e( 'Upload Image', 'zerif-lite' ); ?>" style="margin-top:5px;">
			</p>

			<input class="custom_media_id" id="<?php echo $this->get_field_id( 'custom_media_id' ); ?>"
			       name="<?php echo $this->get_field_name( 'custom_media_id' ); ?>" type="hidden"
			       value="<?php if ( ! empty( $instance["custom_media_id"] ) ): echo $instance["custom_media_id"]; endif; ?>"/>
			<?php

		}

	}
}

/****************************/
/****** team member widget **/
/***************************/

if ( !class_exists( 'zerif_team_widget' ) ) {

	class zerif_team_widget extends WP_Widget {

		public function __construct() {
			parent::__construct(
				'zerif_team-widget',
				__( 'Zerif - Team member widget', 'zerif-lite' ),
				array(
					'customize_selective_refresh' => true,
				)
			);
			add_action( 'admin_enqueue_scripts', array( $this, 'widget_scripts' ) );
		}

		function widget_scripts( $hook ) {
			if ( $hook != 'widgets.php' ) {
				return;
			}
			wp_enqueue_media();
			wp_enqueue_script( 'zerif_widget_media_script', get_template_directory_uri() . '/js/widget-media.js', false, '1.1', true );
		}

		function widget( $args, $instance ) {

			extract( $args );

			echo $before_widget;

			?>

			<div class="col-lg-3 col-sm-3 team-box">

				<div class="team-member" tabindex="0">

					<?php if ( ! empty( $instance['image_uri'] ) && ( $instance['image_uri'] != 'Upload Image' ) ) { ?>


						<figure class="profile-pic">

							<img src="<?php echo esc_url( $instance['image_uri'] ); ?>" alt=""/>

						</figure>
						<?php
					} elseif ( ! empty( $instance['custom_media_id'] ) ) {

						$zerif_team_custom_media_id = wp_get_attachment_image_src( $instance["custom_media_id"] );
						$alt                        = get_post_meta( $instance['custom_media_id'], '_wp_attachment_image_alt', true );

						if ( ! empty( $zerif_team_custom_media_id ) && ! empty( $zerif_team_custom_media_id[0] ) ) {
							?>

							<figure class="profile-pic">

								<img src="<?php echo esc_url( $zerif_team_custom_media_id[0] ); ?>"
								     alt="<?php echo $alt; ?>"/>

							</figure>

							<?php
						}
					}
					?>

					<div class="member-details">

						<?php if ( ! empty( $instance['name'] ) ): ?>

							<h3 class="dark-text red-border-bottom"><?php echo apply_filters( 'widget_title', $instance['name'] ); ?></h3>

						<?php endif; ?>

						<?php if ( ! empty( $instance['position'] ) ): ?>

							<div
								class="position"><?php echo htmlspecialchars_decode( apply_filters( 'widget_title', $instance['position'] ) ); ?></div>

						<?php endif; ?>

					</div>

					<div class="social-icons">

						<ul>
							<?php
							$zerif_team_target = '_self';
							if ( ! empty( $instance['open_new_window'] ) ):
								$zerif_team_target = '_blank';
							endif;
							?>

							<?php
							if ( ! empty( $instance['fb_link'] ) ): ?>
								<li>
									<a href="<?php echo apply_filters( 'widget_title', $instance['fb_link'] ); ?>"
									   target="<?php echo $zerif_team_target; ?>">
										<?php
										if ( ! empty( $instance['name'] ) ) { ?>
											<span class="sr-only">
				                            <?php _e( 'Facebook account of', 'zerif-lite' ); ?>
				                            <?php echo apply_filters( 'widget_title', $instance['name'] ); ?>
			                            </span>
											<?php
										} ?>
										<i class="fa fa-facebook"></i>
									</a>
								</li>
								<?php
							endif;

							if ( ! empty( $instance['tw_link'] ) ): ?>
								<li>
									<a href="<?php echo apply_filters( 'widget_title', $instance['tw_link'] ); ?>"
									   target="<?php echo $zerif_team_target; ?>">
										<?php
										if ( ! empty( $instance['name'] ) ) { ?>
											<span class="sr-only">
				                            <?php _e( 'Twitter account of', 'zerif-lite' ); ?>
				                            <?php echo apply_filters( 'widget_title', $instance['name'] ); ?>
			                            </span>
											<?php
										} ?>
										<i class="fa fa-twitter"></i>
									</a>
								</li>
								<?php
							endif;

							if ( ! empty( $instance['bh_link'] ) ): ?>
								<li>
									<a href="<?php echo apply_filters( 'widget_title', $instance['bh_link'] ); ?>"
									   target="<?php echo $zerif_team_target; ?>">
										<?php
										if ( ! empty( $instance['name'] ) ) { ?>
											<span class="sr-only">
				                            <?php _e( 'Behance account of', 'zerif-lite' ); ?>
				                            <?php echo apply_filters( 'widget_title', $instance['name'] ); ?>
			                            </span>
											<?php
										} ?>
										<i class="fa fa-behance"></i>
									</a>
								</li>
								<?php
							endif;

							if ( ! empty( $instance['db_link'] ) ): ?>
								<li>
									<a href="<?php echo apply_filters( 'widget_title', $instance['db_link'] ); ?>"
									   target="<?php echo $zerif_team_target; ?>">
										<?php
										if ( ! empty( $instance['name'] ) ) { ?>
											<span class="sr-only">
				                            <?php _e( 'Dribble account of', 'zerif-lite' ); ?>
				                            <?php echo apply_filters( 'widget_title', $instance['name'] ); ?>
			                            </span>
											<?php
										} ?>
										<i class="fa fa-dribbble"></i>
									</a>
								</li>
								<?php
							endif;

							if ( ! empty( $instance['ln_link'] ) ): ?>
								<li>
									<a href="<?php echo apply_filters( 'widget_title', $instance['ln_link'] ); ?>"
									   target="<?php echo $zerif_team_target; ?>">
										<?php
										if ( ! empty( $instance['name'] ) ) { ?>
											<span class="sr-only">
				                            <?php _e( 'Linkedin account of', 'zerif-lite' ); ?>
				                            <?php echo apply_filters( 'widget_title', $instance['name'] ); ?>
			                            </span>
											<?php
										} ?>
										<i class="fa fa-linkedin"></i>
									</a>
								</li>
								<?php
							endif; ?>

						</ul>

					</div>

					<?php if ( ! empty( $instance['description'] ) ): ?>
						<div class="details">

							<?php echo htmlspecialchars_decode( apply_filters( 'widget_title', $instance['description'] ) ); ?>

						</div>
					<?php endif; ?>

				</div>

			</div>

			<?php

			echo $after_widget;

		}

		function update( $new_instance, $old_instance ) {

			$instance = $old_instance;

			$instance['name']                = strip_tags( $new_instance['name'] );
			$instance['position']            = stripslashes( wp_filter_post_kses( $new_instance['position'] ) );
			$instance['description']         = stripslashes( wp_filter_post_kses( $new_instance['description'] ) );
			$instance['fb_link']             = strip_tags( $new_instance['fb_link'] );
			$instance['tw_link']             = strip_tags( $new_instance['tw_link'] );
			$instance['bh_link']             = strip_tags( $new_instance['bh_link'] );
			$instance['db_link']             = strip_tags( $new_instance['db_link'] );
			$instance['ln_link']             = strip_tags( $new_instance['ln_link'] );
			$instance['image_uri']           = strip_tags( $new_instance['image_uri'] );
			$instance['open_new_window']     = strip_tags( $new_instance['open_new_window'] );
			$instance['custom_media_id']     = strip_tags( $new_instance['custom_media_id'] );
			$instance['image_in_customizer'] = strip_tags( $new_instance['image_in_customizer'] );

			return $instance;

		}

		function form( $instance ) {

			?>

			<p>
				<label
					for="<?php echo $this->get_field_id( 'name' ); ?>"><?php _e( 'Name', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'name' ); ?>"
				       id="<?php echo $this->get_field_id( 'name' ); ?>"
				       value="<?php if ( ! empty( $instance['name'] ) ): echo $instance['name']; endif; ?>"
				       class="widefat"/>
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'position' ); ?>"><?php _e( 'Position', 'zerif-lite' ); ?></label><br/>
				<textarea class="widefat" rows="8" cols="20" name="<?php echo $this->get_field_name( 'position' ); ?>"
				          id="<?php echo $this->get_field_id( 'position' ); ?>"><?php if ( ! empty( $instance['position'] ) ): echo htmlspecialchars_decode( $instance['position'] ); endif; ?></textarea>
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'description' ); ?>"><?php _e( 'Description', 'zerif-lite' ); ?></label><br/>
				<textarea class="widefat" rows="8" cols="20"
				          name="<?php echo $this->get_field_name( 'description' ); ?>"
				          id="<?php echo $this->get_field_id( 'description' ); ?>"><?php
					if ( ! empty( $instance['description'] ) ): echo htmlspecialchars_decode( $instance['description'] ); endif;
					?></textarea>
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'fb_link' ); ?>"><?php _e( 'Facebook link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'fb_link' ); ?>"
				       id="<?php echo $this->get_field_id( 'fb_link' ); ?>"
				       value="<?php if ( ! empty( $instance['fb_link'] ) ): echo $instance['fb_link']; endif; ?>"
				       class="widefat">

			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'tw_link' ); ?>"><?php _e( 'Twitter link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'tw_link' ); ?>"
				       id="<?php echo $this->get_field_id( 'tw_link' ); ?>"
				       value="<?php if ( ! empty( $instance['tw_link'] ) ): echo $instance['tw_link']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'bh_link' ); ?>"><?php _e( 'Behance link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'bh_link' ); ?>"
				       id="<?php echo $this->get_field_id( 'bh_link' ); ?>"
				       value="<?php if ( ! empty( $instance['bh_link'] ) ): echo $instance['bh_link']; endif; ?>"
				       class="widefat">

			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'db_link' ); ?>"><?php _e( 'Dribble link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'db_link' ); ?>"
				       id="<?php echo $this->get_field_id( 'db_link' ); ?>"
				       value="<?php if ( ! empty( $instance['db_link'] ) ): echo $instance['db_link']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'ln_link' ); ?>"><?php _e( 'Linkedin link', 'zerif-lite' ); ?></label><br/>
				<input type="text" name="<?php echo $this->get_field_name( 'ln_link' ); ?>"
				       id="<?php echo $this->get_field_id( 'ln_link' ); ?>"
				       value="<?php if ( ! empty( $instance['ln_link'] ) ): echo $instance['ln_link']; endif; ?>"
				       class="widefat">
			</p>
			<p>
				<input type="checkbox" name="<?php echo $this->get_field_name( 'open_new_window' ); ?>"
				       id="<?php echo $this->get_field_id( 'open_new_window' ); ?>" <?php if ( ! empty( $instance['open_new_window'] ) ): checked( (bool) $instance['open_new_window'], true ); endif; ?> ><?php _e( 'Open links in new window?', 'zerif-lite' ); ?>
				<br>
			</p>
			<p>
				<label
					for="<?php echo $this->get_field_id( 'image_uri' ); ?>"><?php _e( 'Image', 'zerif-lite' ); ?></label><br/>

				<?php
				$image_in_customizer = '';
				$display             = 'none';
				if ( ! empty( $instance['image_in_customizer'] ) && ! empty( $instance['image_uri'] ) ) {
					$image_in_customizer = esc_url( $instance['image_in_customizer'] );
					$display             = 'inline-block';
				} else {
					if ( ! empty( $instance['image_uri'] ) ) {
						$image_in_customizer = esc_url( $instance['image_uri'] );
						$display             = 'inline-block';
					}
				}
				$zerif_image_in_customizer = $this->get_field_name( 'image_in_customizer' );
				?>
				<input type="hidden" class="custom_media_display_in_customizer"
				       name="<?php if ( ! empty( $zerif_image_in_customizer ) ) {
					       echo $zerif_image_in_customizer;
				       } ?>"
				       value="<?php if ( ! empty( $instance['image_in_customizer'] ) ): echo $instance['image_in_customizer']; endif; ?>">
				<img class="custom_media_image" src="<?php echo $image_in_customizer; ?>"
				     style="margin:0;padding:0;max-width:100px;float:left;display:<?php echo $display; ?>"
				     alt="<?php echo __( 'Uploaded image', 'zerif-lite' ); ?>"/><br/>

				<input type="text" class="widefat custom_media_url"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       id="<?php echo $this->get_field_id( 'image_uri' ); ?>"
				       value="<?php if ( ! empty( $instance['image_uri'] ) ): echo $instance['image_uri']; endif; ?>"
				       style="margin-top:5px;">

				<input type="button" class="button button-primary custom_media_button" id="custom_media_button"
				       name="<?php echo $this->get_field_name( 'image_uri' ); ?>"
				       value="<?php _e( 'Upload Image', 'zerif-lite' ); ?>" style="margin-top:5px;">
			</p>

			<input class="custom_media_id" id="<?php echo $this->get_field_id( 'custom_media_id' ); ?>"
			       name="<?php echo $this->get_field_name( 'custom_media_id' ); ?>" type="hidden"
			       value="<?php if ( ! empty( $instance["custom_media_id"] ) ): echo $instance["custom_media_id"]; endif; ?>"/>

			<?php

		}

	}
}

function zerif_customizer_custom_css() {

    wp_enqueue_style('zerif_customizer_custom_css', get_template_directory_uri() . '/css/zerif_customizer_custom_css.css');

}
add_action('customize_controls_print_styles', 'zerif_customizer_custom_css');


/* Enqueue Google reCAPTCHA scripts */
add_action( 'wp_enqueue_scripts', 'recaptcha_scripts' );

function recaptcha_scripts() {

    if ( is_home() ):
        $zerif_contactus_sitekey = get_theme_mod('zerif_contactus_sitekey');
        $zerif_contactus_secretkey = get_theme_mod('zerif_contactus_secretkey');
        $zerif_contactus_recaptcha_show = get_theme_mod('zerif_contactus_recaptcha_show');
        if( isset($zerif_contactus_recaptcha_show) && $zerif_contactus_recaptcha_show != 1 && !empty($zerif_contactus_sitekey) && !empty($zerif_contactus_secretkey) ) :
            wp_enqueue_script( 'recaptcha', 'https://www.google.com/recaptcha/api.js' );
        endif;
    endif;

}

/* remove custom-background from body_class() */
add_filter( 'body_class', 'remove_class_function' );
function remove_class_function( $classes ) {

    if ( !is_home() && !is_page_template('template-frontpage.php') ) {
        // index of custom-background
        $key = array_search('custom-background', $classes);
        // remove class
        unset($classes[$key]);
    }
    return $classes;

}

/* Update Pirate Forms plugin when there is a change in Customizer Contact us section */

add_action('customize_save_after', 'zerif_lite_update_options_in_pirate_forms', 99);

function zerif_lite_update_options_in_pirate_forms() {

    /* if Pirate Forms is installed */
    if( defined("PIRATE_FORMS_VERSION") ):

        $zerif_lite_current_mods = get_theme_mods(); /* all theme modification values in Customize for Zerif Lite */

        $pirate_forms_settings_array = get_option( 'pirate_forms_settings_array' ); /* Pirate Forms's options's array */

        if( !empty($zerif_lite_current_mods) ):

            if( isset($zerif_lite_current_mods['zerif_contactus_button_label']) ):
                $pirate_forms_settings_array['pirateformsopt_label_submit_btn'] = $zerif_lite_current_mods['zerif_contactus_button_label'];
            endif;

            if( isset($zerif_lite_current_mods['zerif_contactus_email']) ):

                $pirate_forms_settings_array['pirateformsopt_email'] = $zerif_lite_current_mods['zerif_contactus_email'];
                $pirate_forms_settings_array['pirateformsopt_email_recipients'] = $zerif_lite_current_mods['zerif_contactus_email'];

            endif;

            if( isset($zerif_lite_current_mods['zerif_contactus_recaptcha_show']) && ($zerif_lite_current_mods['zerif_contactus_recaptcha_show'] == 1) ):
                if( isset($pirate_forms_settings_array['pirateformsopt_recaptcha_field']) ):
                    unset($pirate_forms_settings_array['pirateformsopt_recaptcha_field']);
                endif;
            else:
                $pirate_forms_settings_array['pirateformsopt_recaptcha_field'] = 'yes';
            endif;

            if( isset($zerif_lite_current_mods['zerif_contactus_sitekey']) ):
                $pirate_forms_settings_array['pirateformsopt_recaptcha_sitekey'] = $zerif_lite_current_mods['zerif_contactus_sitekey'];
            endif;

            if( isset($zerif_lite_current_mods['zerif_contactus_secretkey']) ):
                $pirate_forms_settings_array['pirateformsopt_recaptcha_secretkey'] = $zerif_lite_current_mods['zerif_contactus_secretkey'];
            endif;


        endif;

        if( !empty($pirate_forms_settings_array) ):
            update_option('pirate_forms_settings_array', $pirate_forms_settings_array); /* Update the options */
        endif;

    endif;
}
